/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package soundcardresistometer;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.List;
import javax.sound.sampled.TargetDataLine;
import noise.tools.MeasureResultEvent;
import noise.tools.MeasureResultListener;

/**
 *
 * @author kocsis
 */
public class MeasureProcess extends Thread {

    private boolean stop = false;
    private boolean pause = false;
    private final TargetDataLine targetDataLine;
    private byte[] b = new byte[88];
    private final double[] SIN, COS;
    ByteBuffer bb = ByteBuffer.wrap(b);
    private double avg = 0;
    private final int avgNum;
    List<MeasureResultListener> changeListeners = new ArrayList<MeasureResultListener>();

    MeasureProcess addMeasureResultListener(MeasureResultListener c) {
        changeListeners.add(c);
        return this;
    }

    MeasureProcess removeMeasureResultListener(MeasureResultListener c) {
        changeListeners.remove(c);
        return this;
    }

    MeasureProcess removeAllMeasureResultListener(){
        changeListeners.clear();
        return this;
    }

    public MeasureProcess(TargetDataLine targetDataLine, int avgNum) {
        this.targetDataLine = targetDataLine;
        this.avgNum = avgNum;

        bb.order(ByteOrder.BIG_ENDIAN);

        SIN = new double[44];
        COS = new double[44];

        for (int i = 0; i < SIN.length; i++) {
            SIN[i] = Math.sin(2 * Math.PI * i / 43);
            COS[i] = Math.cos(2 * Math.PI * i / 43);
        }

        targetDataLine.start();
    }

    public void stopReq() {
        stop = true;
    }

    public void pauseReq() {
        pause = true;
    }

    public void resumeReq() {
        pause = false;
    }

    @Override
    public void run() {

        int j = 0;

        while (!stop) {
            double sin = 0;
            double cos = 0;

            targetDataLine.read(b, 0, b.length);
            bb.clear();
            int i = 0;
            while (bb.remaining() >= 2) {
                short curr = bb.getShort();
                sin += SIN[i] * curr;
                cos += COS[i] * curr;
                //jProgressBar1.setValue(curr);
                //data.addData(curr);
                i++;
            }

            if (j == 0) {
                avg = Math.sqrt(sin * sin + cos * cos);
            } else {
                avg += Math.sqrt(sin * sin + cos * cos);
                avg /= 2;
            }
            j++;

            if (j > avgNum) {
                j = 0;
                if (!pause) {
                    final double result = avg;
                    for (final MeasureResultListener c : changeListeners) {
                        java.awt.EventQueue.invokeLater(new Runnable() {

                            public void run() {
                                c.measureResultOccured(new MeasureResultEvent(this, new Double(result)));
                            }
                        });
                    }
                }
            }
        }

        targetDataLine.close();
    }
}
