/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

/*
 * Settings.java
 *
 * Created on 2011.03.03., 10:47:20
 */
package soundcardresistometer;

import java.awt.event.ItemEvent;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.LineUnavailableException;
import javax.sound.sampled.Mixer;
import javax.sound.sampled.SourceDataLine;
import javax.sound.sampled.TargetDataLine;
import javax.swing.JOptionPane;
import javax.swing.JSpinner;
import noise.tools.MeasureResultEvent;
import noise.tools.MeasureResultListener;
import noise.tools.PersistentSettingsManager;
import noise.tools.SoundTools;

/**
 *
 * @author kocsis
 */
public class Settings extends javax.swing.JFrame {

    static final AudioFormat audioFormatMono = new AudioFormat(
            44100, 16, 1, true, true);
    static final AudioFormat audioFormatStereo = new AudioFormat(
            44100, 16, 2, true, true);
    private final PersistentSettingsManager persistentSettingsManager;
    private PlayProcess playProcess = null;
    private MeasureProcess measure = null;
    private NumberFormat nf = NumberFormat.getNumberInstance();
//    final double R0 = 2000;
//    double Rref;
    double A0;

    /** Creates new form Settings */
    public Settings(PersistentSettingsManager persistentSettingsManager) {
        this.persistentSettingsManager = persistentSettingsManager;

        nf.setMaximumFractionDigits(2);
        nf.setMinimumFractionDigits(2);

        initComponents();

        if (persistentSettingsManager.getProperty(SettingKeys.dataType.name()/*dataType.class.getName()*/, dataType.resistance.name()).equals(dataType.resistance.name())) {
            dataTypeGroup.setSelected(resistanceRadioButton.getModel(), true);
        } else {
            dataTypeGroup.setSelected(temperatureRadioButton.getModel(), true);
        }

        if (persistentSettingsManager.getProperty(SettingKeys.temperatureUnit.name()/*temperatureUnit.class.getName()*/, temperatureUnit.celsius.name()).equals(temperatureUnit.celsius.name())) {
            temperatureUnitGroup.setSelected(celsiusRadioButton.getModel(), true);
        } else {
            temperatureUnitGroup.setSelected(farenheightRadioButton.getModel(), true);
        }

        if (Boolean.parseBoolean(persistentSettingsManager.getProperty(SettingKeys.isShowChart.name(), "false"))) {
            jCheckBox1.setSelected(true);
        } else {
            jCheckBox1.setSelected(false);
        }

        if (Boolean.parseBoolean(persistentSettingsManager.getProperty(SettingKeys.isAutoscaleY.name(), "false"))) {
            jCheckBox2.setSelected(true);
        } else {
            jCheckBox2.setSelected(false);
        }

        jSpinner1.setValue(Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.chartWindow.name(), "10")));

  //      Rref = Double.parseDouble(persistentSettingsManager.getProperty(SettingKeys.Rref.name(), "2000.0"));
        A0 = Double.parseDouble(persistentSettingsManager.getProperty(SettingKeys.A0.name(), "100000.0"));

        datarateSpinner.setValue(Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.avgNum.name(), "50")));
        freqLabel.setText(nf.format((float) 44100 / 44 / (Integer) datarateSpinner.getValue()) + " Hz");

        jSpinner2.setValue(Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.displayFontSize.name(), "44")));

        String separator = persistentSettingsManager.getProperty(SettingKeys.columnSeparator.name(), "\t");
        if (separator.equals("\t")) {
            columnSeparatorButtonGroup.setSelected(separatorTabulatorRadioButton.getModel(), true);
        } else if (separator.equals(" ")) {
            columnSeparatorButtonGroup.setSelected(separatorSpaceRadioButton.getModel(), true);
        } else if (separator.equals(",")) {
            columnSeparatorButtonGroup.setSelected(separatorCommaRadioButton.getModel(), true);
        } else {
            columnSeparatorButtonGroup.setSelected(separatorCustomRadioButton.getModel(), true);
            customSeparatorTextField.setText(separator);
        }

        
        //jLabel6.setText
        jSpinner6.setValue(Double.parseDouble(persistentSettingsManager.getProperty(SettingKeys.Rref.name(), "2000.0")));

        for (Mixer.Info info : SoundTools.getMixersWhatsHaveTargetLine(audioFormatMono)) {
            jComboBox1.addItem(info.getName());
        }

        for (Mixer.Info info : SoundTools.getMixersWhatsHaveSourceLine(audioFormatStereo)) {
            jComboBox2.addItem(info.getName());
        }

        Mixer.Info inf = getSavedTargetMixer(persistentSettingsManager);
        if (inf != null){
            jComboBox1.setSelectedItem(inf.getName());
        } else {
            jComboBox1.setSelectedIndex(0);
        }
        inf = getSavedSourceMixer(persistentSettingsManager);
        if (inf != null){
            jComboBox2.setSelectedItem(inf.getName());
        } else {
            jComboBox2.setSelectedIndex(0);
        }

        jSpinner3.setValue(Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.R25.name(), "10000")));
        jSpinner4.setValue(Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.B2580.name(), "3977")));

        jSpinner5.setValue(Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.R0.name(), "2000")));

        pack();


    }

    static Mixer.Info getSavedSourceMixer(PersistentSettingsManager persistentSettingsManager) {
        String sourcename = persistentSettingsManager.getProperty(SettingKeys.sourceDataLineName.name(), "");
        Mixer.Info source = null;
        for (Mixer.Info info : SoundTools.getMixersWhatsHaveSourceLine(audioFormatStereo)) {
            if (info.getName().equals(sourcename)) {
                source = info;
            }
        }

        return source;
    }

    private Mixer.Info getSelectedSourceMixer() {
        String sourcename = (String) jComboBox2.getSelectedItem();
        Mixer.Info source = null;
        for (Mixer.Info info : SoundTools.getMixersWhatsHaveSourceLine(audioFormatStereo)) {
            if (info.getName().equals(sourcename)) {
                source = info;
            }
        }

        return source;
    }

    static Mixer.Info getSavedTargetMixer(PersistentSettingsManager persistentSettingsManager) {
        String targetname = persistentSettingsManager.getProperty(SettingKeys.targetDataLineName.name(), "");
        Mixer.Info target = null;
        for (Mixer.Info info : SoundTools.getMixersWhatsHaveTargetLine(audioFormatMono)) {
            if (info.getName().equals(targetname)) {
                target = info;
            }
        }

        return target;
    }

    private Mixer.Info getSelectedTargetMixer() {
        String targetname = (String) jComboBox1.getSelectedItem();
        Mixer.Info target = null;
        for (Mixer.Info info : SoundTools.getMixersWhatsHaveTargetLine(audioFormatMono)) {
            if (info.getName().equals(targetname)) {
                target = info;
            }
        }

        return target;
    }

    public enum dataType {

        resistance,
        temperature;
    }

    public enum temperatureUnit {

        celsius,
        farenheight;
    }

    public enum SettingKeys {

        isShowChart,
        isAutoscaleY,
        chartWindow,
        displayFontSize,
        avgNum,
        Rref,
        lastExportLocation,
        columnSeparator,
        dataType,
        temperatureUnit,
        targetDataLineName,
        sourceDataLineName,
        R25,
        B2580,
        R0,
        A0;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        dataTypeGroup = new javax.swing.ButtonGroup();
        temperatureUnitGroup = new javax.swing.ButtonGroup();
        columnSeparatorButtonGroup = new javax.swing.ButtonGroup();
        jButton1 = new javax.swing.JButton();
        jTabbedPane1 = new javax.swing.JTabbedPane();
        jPanel1 = new javax.swing.JPanel();
        jPanel4 = new javax.swing.JPanel();
        resistanceRadioButton = new javax.swing.JRadioButton();
        temperatureRadioButton = new javax.swing.JRadioButton();
        jPanel7 = new javax.swing.JPanel();
        celsiusRadioButton = new javax.swing.JRadioButton();
        farenheightRadioButton = new javax.swing.JRadioButton();
        jPanel8 = new javax.swing.JPanel();
        jLabel8 = new javax.swing.JLabel();
        datarateSpinner = new javax.swing.JSpinner();
        jLabel10 = new javax.swing.JLabel();
        freqLabel = new javax.swing.JLabel();
        jLabel9 = new javax.swing.JLabel();
        jSpinner2 = new javax.swing.JSpinner();
        jLabel11 = new javax.swing.JLabel();
        jPanel2 = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        jSpinner1 = new javax.swing.JSpinner();
        jLabel2 = new javax.swing.JLabel();
        jCheckBox2 = new javax.swing.JCheckBox();
        jCheckBox1 = new javax.swing.JCheckBox();
        jPanel9 = new javax.swing.JPanel();
        separatorTabulatorRadioButton = new javax.swing.JRadioButton();
        separatorSpaceRadioButton = new javax.swing.JRadioButton();
        separatorCustomRadioButton = new javax.swing.JRadioButton();
        customSeparatorTextField = new javax.swing.JTextField();
        separatorCommaRadioButton = new javax.swing.JRadioButton();
        jPanel3 = new javax.swing.JPanel();
        jPanel5 = new javax.swing.JPanel();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        jPanel6 = new javax.swing.JPanel();
        jLabel7 = new javax.swing.JLabel();
        jButton2 = new javax.swing.JButton();
        jLabel5 = new javax.swing.JLabel();
        jLabel16 = new javax.swing.JLabel();
        jSpinner5 = new javax.swing.JSpinner();
        jSpinner6 = new javax.swing.JSpinner();
        jLabel17 = new javax.swing.JLabel();
        jPanel11 = new javax.swing.JPanel();
        jLabel14 = new javax.swing.JLabel();
        jSpinner3 = new javax.swing.JSpinner();
        jLabel15 = new javax.swing.JLabel();
        jSpinner4 = new javax.swing.JSpinner();
        jLabel18 = new javax.swing.JLabel();
        jPanel10 = new javax.swing.JPanel();
        jLabel12 = new javax.swing.JLabel();
        jLabel13 = new javax.swing.JLabel();
        jComboBox1 = new javax.swing.JComboBox();
        jComboBox2 = new javax.swing.JComboBox();
        jButton3 = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setResizable(false);

        jButton1.setText("Save");
        jButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButton1ActionPerformed(evt);
            }
        });

        jTabbedPane1.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                jTabbedPane1StateChanged(evt);
            }
        });

        jPanel4.setBorder(javax.swing.BorderFactory.createTitledBorder("Show data as"));

        dataTypeGroup.add(resistanceRadioButton);
        resistanceRadioButton.setText("Resistance");

        dataTypeGroup.add(temperatureRadioButton);
        temperatureRadioButton.setText("Temperature");

        javax.swing.GroupLayout jPanel4Layout = new javax.swing.GroupLayout(jPanel4);
        jPanel4.setLayout(jPanel4Layout);
        jPanel4Layout.setHorizontalGroup(
            jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel4Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(resistanceRadioButton)
                    .addComponent(temperatureRadioButton))
                .addContainerGap(34, Short.MAX_VALUE))
        );
        jPanel4Layout.setVerticalGroup(
            jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel4Layout.createSequentialGroup()
                .addComponent(resistanceRadioButton)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(temperatureRadioButton))
        );

        jPanel7.setBorder(javax.swing.BorderFactory.createTitledBorder("Temperature unit"));

        temperatureUnitGroup.add(celsiusRadioButton);
        celsiusRadioButton.setText("Celsius");

        temperatureUnitGroup.add(farenheightRadioButton);
        farenheightRadioButton.setText("Farenheight");

        javax.swing.GroupLayout jPanel7Layout = new javax.swing.GroupLayout(jPanel7);
        jPanel7.setLayout(jPanel7Layout);
        jPanel7Layout.setHorizontalGroup(
            jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel7Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(celsiusRadioButton)
                    .addComponent(farenheightRadioButton))
                .addContainerGap(38, Short.MAX_VALUE))
        );
        jPanel7Layout.setVerticalGroup(
            jPanel7Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel7Layout.createSequentialGroup()
                .addComponent(celsiusRadioButton)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(farenheightRadioButton))
        );

        jPanel8.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createTitledBorder("Averaging")));

        jLabel8.setText("Averages number:");

        datarateSpinner.setModel(new javax.swing.SpinnerNumberModel(50, 1, 1000, 1));
        datarateSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                datarateSpinnerStateChanged(evt);
            }
        });

        jLabel10.setText("Data refresh frequency:");

        freqLabel.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        freqLabel.setText("jLabel11");

        javax.swing.GroupLayout jPanel8Layout = new javax.swing.GroupLayout(jPanel8);
        jPanel8.setLayout(jPanel8Layout);
        jPanel8Layout.setHorizontalGroup(
            jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel8Layout.createSequentialGroup()
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jLabel8)
                    .addComponent(jLabel10))
                .addGap(18, 18, 18)
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(freqLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 224, Short.MAX_VALUE)
                    .addComponent(datarateSpinner, javax.swing.GroupLayout.DEFAULT_SIZE, 224, Short.MAX_VALUE)))
        );
        jPanel8Layout.setVerticalGroup(
            jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel8Layout.createSequentialGroup()
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel8)
                    .addComponent(datarateSpinner, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel8Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel10)
                    .addComponent(freqLabel)))
        );

        jLabel9.setText("Display font size:");

        jSpinner2.setModel(new javax.swing.SpinnerNumberModel(44, 8, 200, 1));

        jLabel11.setText("Pt");

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jPanel8, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addComponent(jPanel4, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jPanel7, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(jPanel1Layout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addComponent(jLabel9)
                        .addGap(52, 52, 52)
                        .addComponent(jSpinner2, javax.swing.GroupLayout.PREFERRED_SIZE, 59, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel11)))
                .addContainerGap())
        );

        jPanel1Layout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {jPanel4, jPanel7});

        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jPanel4, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jPanel7, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jPanel8, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel9)
                    .addComponent(jSpinner2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel11))
                .addGap(101, 101, 101))
        );

        jTabbedPane1.addTab("View control", jPanel1);

        jLabel1.setText("Displayed (and exportable) time window:");

        jSpinner1.setModel(new javax.swing.SpinnerNumberModel(10, 1, 60, 1));

        jLabel2.setText("s");

        jCheckBox2.setText("Autoscale Y axis");

        jCheckBox1.setFont(new java.awt.Font("Tahoma", 1, 11));
        jCheckBox1.setText("Enable chart");

        jPanel9.setBorder(javax.swing.BorderFactory.createTitledBorder("Column separator"));

        columnSeparatorButtonGroup.add(separatorTabulatorRadioButton);
        separatorTabulatorRadioButton.setText("Tabulator");

        columnSeparatorButtonGroup.add(separatorSpaceRadioButton);
        separatorSpaceRadioButton.setText("Space");

        columnSeparatorButtonGroup.add(separatorCustomRadioButton);
        separatorCustomRadioButton.setText("Custom");
        separatorCustomRadioButton.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                separatorCustomRadioButtonItemStateChanged(evt);
            }
        });

        customSeparatorTextField.setEnabled(false);

        columnSeparatorButtonGroup.add(separatorCommaRadioButton);
        separatorCommaRadioButton.setText("Comma");

        javax.swing.GroupLayout jPanel9Layout = new javax.swing.GroupLayout(jPanel9);
        jPanel9.setLayout(jPanel9Layout);
        jPanel9Layout.setHorizontalGroup(
            jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel9Layout.createSequentialGroup()
                .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel9Layout.createSequentialGroup()
                        .addComponent(separatorTabulatorRadioButton)
                        .addGap(18, 18, 18)
                        .addComponent(separatorCommaRadioButton))
                    .addGroup(jPanel9Layout.createSequentialGroup()
                        .addComponent(separatorSpaceRadioButton)
                        .addGap(34, 34, 34)
                        .addComponent(separatorCustomRadioButton)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(customSeparatorTextField, javax.swing.GroupLayout.DEFAULT_SIZE, 201, Short.MAX_VALUE)))
                .addContainerGap())
        );
        jPanel9Layout.setVerticalGroup(
            jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel9Layout.createSequentialGroup()
                .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(separatorTabulatorRadioButton)
                    .addComponent(separatorCommaRadioButton))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel9Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(separatorSpaceRadioButton)
                    .addComponent(customSeparatorTextField, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(separatorCustomRadioButton))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jPanel9, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jCheckBox1)
                    .addComponent(jCheckBox2)
                    .addGroup(jPanel2Layout.createSequentialGroup()
                        .addComponent(jLabel1)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                        .addComponent(jSpinner1, javax.swing.GroupLayout.PREFERRED_SIZE, 61, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jLabel2)))
                .addContainerGap())
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jCheckBox1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jCheckBox2)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel1)
                    .addComponent(jSpinner1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel2))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jPanel9, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(138, Short.MAX_VALUE))
        );

        jTabbedPane1.addTab("Chart and Export settings", jPanel2);

        jPanel5.setBorder(javax.swing.BorderFactory.createTitledBorder("Feedback calibration"));

        jLabel3.setText("Volume:");

        jLabel4.setText("?");

        jPanel6.setBackground(new java.awt.Color(204, 204, 0));
        jPanel6.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                jPanel6MouseClicked(evt);
            }
        });

        javax.swing.GroupLayout jPanel6Layout = new javax.swing.GroupLayout(jPanel6);
        jPanel6.setLayout(jPanel6Layout);
        jPanel6Layout.setHorizontalGroup(
            jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 35, Short.MAX_VALUE)
        );
        jPanel6Layout.setVerticalGroup(
            jPanel6Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 27, Short.MAX_VALUE)
        );

        jLabel7.setText("Ohm");

        jButton2.setText("Do calibration");
        jButton2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButton2ActionPerformed(evt);
            }
        });

        jLabel5.setText("Microphone pullup resistor:");

        jLabel16.setText("R0:");

        jSpinner5.setModel(new javax.swing.SpinnerNumberModel(2000, 1, 20000, 1));

        jSpinner6.setModel(new javax.swing.SpinnerNumberModel(Double.valueOf(500.0d), Double.valueOf(500.0d), null, Double.valueOf(1.0d)));

        jLabel17.setText("Ohm");

        javax.swing.GroupLayout jPanel5Layout = new javax.swing.GroupLayout(jPanel5);
        jPanel5.setLayout(jPanel5Layout);
        jPanel5Layout.setHorizontalGroup(
            jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel5Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel5Layout.createSequentialGroup()
                        .addComponent(jButton2, javax.swing.GroupLayout.DEFAULT_SIZE, 347, Short.MAX_VALUE)
                        .addContainerGap())
                    .addGroup(jPanel5Layout.createSequentialGroup()
                        .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                            .addGroup(javax.swing.GroupLayout.Alignment.LEADING, jPanel5Layout.createSequentialGroup()
                                .addComponent(jLabel3)
                                .addGap(18, 18, 18)
                                .addComponent(jLabel4, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                .addComponent(jPanel6, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                            .addGroup(javax.swing.GroupLayout.Alignment.LEADING, jPanel5Layout.createSequentialGroup()
                                .addComponent(jLabel16)
                                .addGap(18, 18, 18)
                                .addComponent(jSpinner5))
                            .addGroup(javax.swing.GroupLayout.Alignment.LEADING, jPanel5Layout.createSequentialGroup()
                                .addComponent(jLabel5)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                .addComponent(jSpinner6, javax.swing.GroupLayout.PREFERRED_SIZE, 114, javax.swing.GroupLayout.PREFERRED_SIZE)))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(jLabel7)
                            .addComponent(jLabel17))
                        .addGap(78, 78, 78))))
        );
        jPanel5Layout.setVerticalGroup(
            jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel5Layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jButton2)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                        .addComponent(jLabel3)
                        .addComponent(jLabel4))
                    .addComponent(jPanel6, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel5)
                    .addComponent(jSpinner6, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel7))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel5Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel16)
                    .addComponent(jSpinner5, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel17))
                .addContainerGap(15, Short.MAX_VALUE))
        );

        jPanel11.setBorder(javax.swing.BorderFactory.createTitledBorder("Thermistor parameters"));

        jLabel14.setText("R_25:");

        jSpinner3.setModel(new javax.swing.SpinnerNumberModel(10000, 1, 1000000, 1));

        jLabel15.setText("B_25/80:");

        jSpinner4.setModel(new javax.swing.SpinnerNumberModel(3977, 1, 10000, 1));

        jLabel18.setText("Ohm");

        javax.swing.GroupLayout jPanel11Layout = new javax.swing.GroupLayout(jPanel11);
        jPanel11.setLayout(jPanel11Layout);
        jPanel11Layout.setHorizontalGroup(
            jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel11Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jLabel14)
                    .addComponent(jLabel15))
                .addGap(25, 25, 25)
                .addGroup(jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jSpinner4)
                    .addComponent(jSpinner3, javax.swing.GroupLayout.DEFAULT_SIZE, 142, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jLabel18)
                .addContainerGap(120, Short.MAX_VALUE))
        );
        jPanel11Layout.setVerticalGroup(
            jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel11Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel14)
                    .addComponent(jSpinner3, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel18))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel11Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel15)
                    .addComponent(jSpinner4, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        javax.swing.GroupLayout jPanel3Layout = new javax.swing.GroupLayout(jPanel3);
        jPanel3.setLayout(jPanel3Layout);
        jPanel3Layout.setHorizontalGroup(
            jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel3Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jPanel5, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jPanel11, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap())
        );
        jPanel3Layout.setVerticalGroup(
            jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel3Layout.createSequentialGroup()
                .addComponent(jPanel5, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jPanel11, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(40, Short.MAX_VALUE))
        );

        jTabbedPane1.addTab("Calibration", jPanel3);

        jLabel12.setText("Input Mixer:");

        jLabel13.setText("Output Mixer:");

        javax.swing.GroupLayout jPanel10Layout = new javax.swing.GroupLayout(jPanel10);
        jPanel10.setLayout(jPanel10Layout);
        jPanel10Layout.setHorizontalGroup(
            jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel10Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(jPanel10Layout.createSequentialGroup()
                        .addComponent(jLabel12)
                        .addGap(23, 23, 23)
                        .addComponent(jComboBox1, 0, 297, Short.MAX_VALUE))
                    .addGroup(jPanel10Layout.createSequentialGroup()
                        .addComponent(jLabel13)
                        .addGap(15, 15, 15)
                        .addComponent(jComboBox2, 0, 297, Short.MAX_VALUE)))
                .addContainerGap())
        );
        jPanel10Layout.setVerticalGroup(
            jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel10Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel12)
                    .addComponent(jComboBox1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(jPanel10Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel13)
                    .addComponent(jComboBox2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap(245, Short.MAX_VALUE))
        );

        jTabbedPane1.addTab("Select Soundcard", jPanel10);

        jButton3.setText("Cancel");
        jButton3.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButton3ActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(jTabbedPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 404, Short.MAX_VALUE)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap(266, Short.MAX_VALUE)
                .addComponent(jButton1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jButton3)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(jTabbedPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 330, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jButton3)
                    .addComponent(jButton1))
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void jButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton1ActionPerformed
        //save things
        if (dataTypeGroup.getSelection().equals(resistanceRadioButton.getModel())) {
            persistentSettingsManager.setProperty(SettingKeys.dataType.name()/*dataType.class.getName()*/, dataType.resistance.name());
        } else {
            persistentSettingsManager.setProperty(SettingKeys.dataType.name()/*dataType.class.getName()*/, dataType.temperature.name());
        }

        if (temperatureUnitGroup.getSelection().equals(celsiusRadioButton.getModel())) {
            persistentSettingsManager.setProperty(SettingKeys.temperatureUnit.name()/*temperatureUnit.class.getName()*/, temperatureUnit.celsius.name());
        } else {
            persistentSettingsManager.setProperty(SettingKeys.temperatureUnit.name()/*temperatureUnit.class.getName()*/, temperatureUnit.farenheight.name());
        }

        persistentSettingsManager.setProperty(SettingKeys.isShowChart.name(), jCheckBox1.isSelected() + "");
        persistentSettingsManager.setProperty(SettingKeys.isAutoscaleY.name(), jCheckBox2.isSelected() + "");

        persistentSettingsManager.setProperty(SettingKeys.chartWindow.name(), jSpinner1.getValue() + "");

        persistentSettingsManager.setProperty(SettingKeys.A0.name(), A0 + "");
        persistentSettingsManager.setProperty(SettingKeys.Rref.name(), jSpinner6.getValue().toString());

        persistentSettingsManager.setProperty(SettingKeys.avgNum.name(), datarateSpinner.getValue().toString());

        persistentSettingsManager.setProperty(SettingKeys.displayFontSize.name(), jSpinner2.getValue() + "");

        String separator;
        if (columnSeparatorButtonGroup.getSelection().equals(separatorCommaRadioButton.getModel())) {
            separator = ",";
        } else if (columnSeparatorButtonGroup.getSelection().equals(separatorSpaceRadioButton.getModel())) {
            separator = " ";
        } else if (columnSeparatorButtonGroup.getSelection().equals(separatorTabulatorRadioButton.getModel())) {
            separator = "\t";
        } else {
            separator = customSeparatorTextField.getText();
        }
        persistentSettingsManager.setProperty(SettingKeys.columnSeparator.name(), separator);

        persistentSettingsManager.setProperty(SettingKeys.targetDataLineName.name(), jComboBox1.getSelectedItem().toString());
        persistentSettingsManager.setProperty(SettingKeys.sourceDataLineName.name(), jComboBox2.getSelectedItem().toString());

        persistentSettingsManager.setProperty(SettingKeys.R25.name(), jSpinner3.getValue().toString());
        persistentSettingsManager.setProperty(SettingKeys.B2580.name(), jSpinner4.getValue().toString());

        persistentSettingsManager.setProperty(SettingKeys.R0.name(), jSpinner5.getValue().toString());

        dispose();
    }//GEN-LAST:event_jButton1ActionPerformed

    private void jPanel6MouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_jPanel6MouseClicked
}//GEN-LAST:event_jPanel6MouseClicked

    private void jButton2ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton2ActionPerformed
        if (measure != null) {
            //JOptionPane.showMessageDialog(this, "Now let's claibrate.");
            final List<Double> amps = new ArrayList(2);
            final int R0 = Integer.parseInt(persistentSettingsManager.getProperty(SettingKeys.R0.name(), "2000"));

            amps.add(Double.NaN);
            amps.add(new Double(0));

            measure.removeAllMeasureResultListener();
            measure.addMeasureResultListener(new MeasureResultListener() {

                public void measureResultOccured(MeasureResultEvent mre) {
                    if (amps.get(1).isNaN()) {
                        amps.set(1, mre.getResult());

                        measure.stopReq();
                        playProcess.stopReq();

                        double C = (double) R0 / (R0 + 10000);
                        A0 = (amps.get(0) * amps.get(1) * (C - 1)) / (C * amps.get(0) - amps.get(1));
                        double Rref = (double) R0 / (A0 / amps.get(0) - 1);

                        persistentSettingsManager.setProperty("A0", A0 + "");
                       // persistentSettingsManager.setProperty("Rref", Rref + "");
                       // jLabel6.setText(nf.format(Rref));
                        jSpinner6.setValue(Rref);

                        jButton2.setEnabled(true);

                        JOptionPane.showMessageDialog(Settings.this, "Calibration complete.");
                        jButton2.setText("Do calibration");
                        measure = null;
                        playProcess = null;
                    }
                    if (amps.get(0).isNaN()) {
                        amps.set(0, mre.getResult());
                        measure.pauseReq();
                        JOptionPane.showMessageDialog(Settings.this, "Now please insert the 10k");
                        measure.resumeReq();
                        amps.set(1, Double.NaN);
                    }
                }
            });

        } else {
            try {
                TargetDataLine targetDataLine = AudioSystem.getTargetDataLine(audioFormatMono, getSelectedTargetMixer());
                SourceDataLine sourceDataLine = AudioSystem.getSourceDataLine(audioFormatStereo, getSelectedSourceMixer());
                targetDataLine.open(audioFormatMono);
                sourceDataLine.open(audioFormatStereo);

                JOptionPane.showMessageDialog(this, "Now you should adjust the input and output volume.\n"
                        + "Please put a short circuit into the jack.\n"
                        + "When the yellow box will be green the volume will be optimal.\n"
                        );

                playProcess = new PlayProcess(sourceDataLine);
                playProcess.setDaemon(true);
                playProcess.start();

                measure = new MeasureProcess(targetDataLine, 1000);
                measure.addMeasureResultListener(new MeasureResultListener() {

                    public void measureResultOccured(MeasureResultEvent mre) {
                        if (mre.getResult() > 704490 / 2) {
                            jPanel6.setBackground(new java.awt.Color(255, 0, 0));
                            jLabel4.setText("too loud");
                        } else if (mre.getResult() < 704490 / 5) {
                            jPanel6.setBackground(new java.awt.Color(0, 0, 255));
                            jLabel4.setText("too quiet");
                        } else {
                            jPanel6.setBackground(new java.awt.Color(0, 255, 0));
                            jLabel4.setText("optimal");
                        }
                    }
                });
                measure.setDaemon(true);
                measure.start();
                //jButton2.setEnabled(false);
                jButton2.setText("Next");

            } catch (LineUnavailableException ex) {
                JOptionPane.showMessageDialog(this, "Can not get access to sound system", "", JOptionPane.ERROR_MESSAGE);
                measure=null;
                Logger.getLogger(Settings.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
    }//GEN-LAST:event_jButton2ActionPerformed

    private void jButton3ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton3ActionPerformed
        dispose();
    }//GEN-LAST:event_jButton3ActionPerformed

    private void datarateSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_datarateSpinnerStateChanged
        javax.swing.JSpinner spinner = (JSpinner) evt.getSource();
        freqLabel.setText(nf.format((float) 44000 / 44 / (Integer) spinner.getValue()) + " Hz");
    }//GEN-LAST:event_datarateSpinnerStateChanged

    private void separatorCustomRadioButtonItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_separatorCustomRadioButtonItemStateChanged
        if (evt.getStateChange() == ItemEvent.SELECTED) {
            customSeparatorTextField.setEnabled(true);
        } else {
            customSeparatorTextField.setEnabled(false);
        }
    }//GEN-LAST:event_separatorCustomRadioButtonItemStateChanged

    private void jTabbedPane1StateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_jTabbedPane1StateChanged
    }//GEN-LAST:event_jTabbedPane1StateChanged
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JRadioButton celsiusRadioButton;
    private javax.swing.ButtonGroup columnSeparatorButtonGroup;
    private javax.swing.JTextField customSeparatorTextField;
    private javax.swing.ButtonGroup dataTypeGroup;
    private javax.swing.JSpinner datarateSpinner;
    private javax.swing.JRadioButton farenheightRadioButton;
    private javax.swing.JLabel freqLabel;
    private javax.swing.JButton jButton1;
    private javax.swing.JButton jButton2;
    private javax.swing.JButton jButton3;
    private javax.swing.JCheckBox jCheckBox1;
    private javax.swing.JCheckBox jCheckBox2;
    private javax.swing.JComboBox jComboBox1;
    private javax.swing.JComboBox jComboBox2;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel10;
    private javax.swing.JPanel jPanel11;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel3;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JPanel jPanel5;
    private javax.swing.JPanel jPanel6;
    private javax.swing.JPanel jPanel7;
    private javax.swing.JPanel jPanel8;
    private javax.swing.JPanel jPanel9;
    private javax.swing.JSpinner jSpinner1;
    private javax.swing.JSpinner jSpinner2;
    private javax.swing.JSpinner jSpinner3;
    private javax.swing.JSpinner jSpinner4;
    private javax.swing.JSpinner jSpinner5;
    private javax.swing.JSpinner jSpinner6;
    private javax.swing.JTabbedPane jTabbedPane1;
    private javax.swing.JRadioButton resistanceRadioButton;
    private javax.swing.JRadioButton separatorCommaRadioButton;
    private javax.swing.JRadioButton separatorCustomRadioButton;
    private javax.swing.JRadioButton separatorSpaceRadioButton;
    private javax.swing.JRadioButton separatorTabulatorRadioButton;
    private javax.swing.JRadioButton temperatureRadioButton;
    private javax.swing.ButtonGroup temperatureUnitGroup;
    // End of variables declaration//GEN-END:variables
}
