/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

/*
 * SoundCardResistometer.java
 *
 * Created on 2011.03.03., 8:42:44
 */
package soundcardresistometer;

import java.awt.Cursor;
import java.awt.Font;
import java.awt.event.ItemEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.BufferedOutputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.text.NumberFormat;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.LineUnavailableException;
import javax.sound.sampled.Mixer;
import javax.sound.sampled.SourceDataLine;
import javax.sound.sampled.TargetDataLine;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.MenuElement;
import noise.chart.XYArray;
import noise.chart.dXYCircularBuffer;
import noise.tools.ClipboardUtils;
import noise.tools.MeasureResultEvent;
import noise.tools.MeasureResultListener;
import noise.tools.PersistentSettingsManager;
import noise.tools.VersionNumber;
import noise.tools.gui.GuiTools;

/**
 *
 * @author kocsis
 */
public class SoundcardOhmmeter extends javax.swing.JFrame {

    public final static VersionNumber versionNumber = VersionNumber.buildVersionNumber("1.0");
    private final PersistentSettingsManager persistentSettingsManager;
    private MeasureProcess measureProcess;
    private PlayProcess playProcess;
    private dXYCircularBuffer data;
    private final NumberFormat nf = NumberFormat.getNumberInstance();

    /** Creates new form SoundCardResistometer */
    public SoundcardOhmmeter() {
        initComponents();
        this.setTitle(this.getClass().getSimpleName());
        persistentSettingsManager = new PersistentSettingsManager(this.getClass().getSimpleName());
        this.addWindowListener(persistentSettingsManager);
        this.addComponentListener(persistentSettingsManager);
        persistentSettingsManager.restoreComponentProperties(this);

        chartXY1.getXscale().autoscale(true);
        chartXY1.getXscale().setLabel("Time [s]");

        stopButton.setEnabled(false);
        jMenu3.setEnabled(false);

        if (persistentSettingsManager.getProperty(Settings.SettingKeys.Rref.name()) == null) {
            JOptionPane.showMessageDialog(this, "Seems like you have not calibrated your sound system yet.\n"
                    + "Please go in Settings and do it.", null, WIDTH);
        }

        updateView();

    }

    final void updateView() {
        chartXY1.setVisible(Boolean.parseBoolean(persistentSettingsManager.getProperty(Settings.SettingKeys.isShowChart.name(), "false")));
        if (chartXY1.isVisible() == true) {
            exportChartMenuItem.setEnabled(true);
        } else {
            exportChartMenuItem.setEnabled(false);
        }
        jCheckBox1.setSelected(Boolean.parseBoolean(persistentSettingsManager.getProperty(Settings.SettingKeys.isAutoscaleY.name(), "false")));
        Font font = resultLabel.getFont();
        int size = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.displayFontSize.name(), "44"));
        font = new Font(font.getFontName(), font.getStyle(), size);
        resultLabel.setFont(font);

        if (persistentSettingsManager.getProperty(Settings.SettingKeys.dataType.name()/*Settings.dataType.class.getName()*/, Settings.dataType.resistance.name()).equals(Settings.dataType.temperature.name())) {
            nf.setMaximumFractionDigits(1);
            nf.setMinimumFractionDigits(1);
            if (persistentSettingsManager.getProperty(Settings.SettingKeys.temperatureUnit.name()/*Settings.temperatureUnit.class.getName()*/, Settings.temperatureUnit.celsius.name()).equals(Settings.temperatureUnit.celsius.name())) {
                unitLabel.setText("°C");
            } else {
                unitLabel.setText("°F");
            }
        } else {
            unitLabel.setText("Ohm");
            nf.setMaximumFractionDigits(0);
            nf.setMinimumFractionDigits(0);
        }

        if(persistentSettingsManager.getProperty(Settings.SettingKeys.dataType.name(), Settings.dataType.resistance.name()).equals(Settings.dataType.resistance.name())){
            buttonGroup1.setSelected(jRadioButton2.getModel(), true);
        } else {
            buttonGroup1.setSelected(jRadioButton1.getModel(), true);
        }

        chartXY1.getYscale().setLabel(unitLabel.getText());
        resultLabel.setText("?");
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        buttonGroup1 = new javax.swing.ButtonGroup();
        chartXY1 = new noise.chart.ChartXY();
        jPanel1 = new javax.swing.JPanel();
        resultLabel = new javax.swing.JLabel();
        unitLabel = new javax.swing.JLabel();
        jPanel2 = new javax.swing.JPanel();
        startButton = new javax.swing.JButton();
        stopButton = new javax.swing.JButton();
        jPanel3 = new javax.swing.JPanel();
        startButton1 = new javax.swing.JButton();
        startButton2 = new javax.swing.JButton();
        jCheckBox1 = new javax.swing.JCheckBox();
        jPanel4 = new javax.swing.JPanel();
        jRadioButton1 = new javax.swing.JRadioButton();
        jRadioButton2 = new javax.swing.JRadioButton();
        jMenuBar1 = new javax.swing.JMenuBar();
        jMenu4 = new javax.swing.JMenu();
        jMenuItem1 = new javax.swing.JMenuItem();
        jMenu3 = new javax.swing.JMenu();
        exportChartMenuItem = new javax.swing.JMenuItem();
        jMenuItem3 = new javax.swing.JMenuItem();
        jMenuItem4 = new javax.swing.JMenuItem();
        jMenu2 = new javax.swing.JMenu();
        jMenuItem2 = new javax.swing.JMenuItem();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);

        chartXY1.setMinimumSize(new java.awt.Dimension(0, 300));

        javax.swing.GroupLayout chartXY1Layout = new javax.swing.GroupLayout(chartXY1);
        chartXY1.setLayout(chartXY1Layout);
        chartXY1Layout.setHorizontalGroup(
            chartXY1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 495, Short.MAX_VALUE)
        );
        chartXY1Layout.setVerticalGroup(
            chartXY1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 356, Short.MAX_VALUE)
        );

        jPanel1.setBorder(javax.swing.BorderFactory.createEtchedBorder());

        resultLabel.setFont(new java.awt.Font("Tahoma", 0, 48)); // NOI18N
        resultLabel.setText("?");

        unitLabel.setFont(new java.awt.Font("Tahoma", 0, 24)); // NOI18N
        unitLabel.setText("Ohm");

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanel1Layout.createSequentialGroup()
                .addContainerGap(237, Short.MAX_VALUE)
                .addComponent(resultLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addComponent(unitLabel)
                .addContainerGap(161, Short.MAX_VALUE))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(unitLabel)
                    .addComponent(resultLabel))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        jPanel2.setBorder(javax.swing.BorderFactory.createTitledBorder("Controls"));

        startButton.setText("Start");
        startButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                startButtonActionPerformed(evt);
            }
        });

        stopButton.setText("Stop");
        stopButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                stopButtonActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel2Layout = new javax.swing.GroupLayout(jPanel2);
        jPanel2.setLayout(jPanel2Layout);
        jPanel2Layout.setHorizontalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(startButton, javax.swing.GroupLayout.DEFAULT_SIZE, 81, Short.MAX_VALUE)
                    .addComponent(stopButton, javax.swing.GroupLayout.DEFAULT_SIZE, 81, Short.MAX_VALUE))
                .addContainerGap())
        );
        jPanel2Layout.setVerticalGroup(
            jPanel2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel2Layout.createSequentialGroup()
                .addComponent(startButton)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(stopButton))
        );

        jPanel3.setBorder(javax.swing.BorderFactory.createTitledBorder("Chart"));

        startButton1.setText("Show");
        startButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                startButton1ActionPerformed(evt);
            }
        });

        startButton2.setText("Autoscale");
        startButton2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                startButton2ActionPerformed(evt);
            }
        });

        jCheckBox1.setText("Autoscaling");
        jCheckBox1.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                jCheckBox1ItemStateChanged(evt);
            }
        });

        javax.swing.GroupLayout jPanel3Layout = new javax.swing.GroupLayout(jPanel3);
        jPanel3.setLayout(jPanel3Layout);
        jPanel3Layout.setHorizontalGroup(
            jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel3Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING, false)
                    .addComponent(startButton1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jCheckBox1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(startButton2, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        jPanel3Layout.setVerticalGroup(
            jPanel3Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel3Layout.createSequentialGroup()
                .addComponent(startButton1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jCheckBox1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(startButton2)
                .addContainerGap())
        );

        jPanel4.setBorder(javax.swing.BorderFactory.createTitledBorder("Data as"));

        buttonGroup1.add(jRadioButton1);
        jRadioButton1.setText("Temperature");
        jRadioButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jRadioButton1ActionPerformed(evt);
            }
        });

        buttonGroup1.add(jRadioButton2);
        jRadioButton2.setText("Resistance");
        jRadioButton2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jRadioButton2ActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout jPanel4Layout = new javax.swing.GroupLayout(jPanel4);
        jPanel4.setLayout(jPanel4Layout);
        jPanel4Layout.setHorizontalGroup(
            jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel4Layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jRadioButton1)
                    .addComponent(jRadioButton2))
                .addContainerGap(8, Short.MAX_VALUE))
        );
        jPanel4Layout.setVerticalGroup(
            jPanel4Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(jPanel4Layout.createSequentialGroup()
                .addComponent(jRadioButton1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jRadioButton2))
        );

        jMenu4.setText("Settings");

        jMenuItem1.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_S, java.awt.event.InputEvent.CTRL_MASK));
        jMenuItem1.setText("Settings/Calibration");
        jMenuItem1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jMenuItem1ActionPerformed(evt);
            }
        });
        jMenu4.add(jMenuItem1);

        jMenuBar1.add(jMenu4);

        jMenu3.setText("Export");

        exportChartMenuItem.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_J, java.awt.event.InputEvent.CTRL_MASK));
        exportChartMenuItem.setText("Export chart as JPEG...");
        exportChartMenuItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exportChartMenuItemActionPerformed(evt);
            }
        });
        jMenu3.add(exportChartMenuItem);

        jMenuItem3.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_P, java.awt.event.InputEvent.CTRL_MASK));
        jMenuItem3.setText("Export data as plain text...");
        jMenuItem3.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jMenuItem3ActionPerformed(evt);
            }
        });
        jMenu3.add(jMenuItem3);

        jMenuItem4.setAccelerator(javax.swing.KeyStroke.getKeyStroke(java.awt.event.KeyEvent.VK_C, java.awt.event.InputEvent.CTRL_MASK));
        jMenuItem4.setText("Copy data to clipboard");
        jMenuItem4.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jMenuItem4ActionPerformed(evt);
            }
        });
        jMenu3.add(jMenuItem4);

        jMenuBar1.add(jMenu3);

        jMenu2.setText("Help");

        jMenuItem2.setText("About...");
        jMenuItem2.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jMenuItem2ActionPerformed(evt);
            }
        });
        jMenu2.add(jMenuItem2);

        jMenuBar1.add(jMenu2);

        setJMenuBar(jMenuBar1);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGap(10, 10, 10)
                        .addComponent(jPanel1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                    .addComponent(chartXY1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                    .addComponent(jPanel4, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jPanel3, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                    .addComponent(jPanel2, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jPanel1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jPanel2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(jPanel3, javax.swing.GroupLayout.PREFERRED_SIZE, 99, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(jPanel4, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addContainerGap())
                    .addComponent(chartXY1, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void startButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_startButtonActionPerformed
        try {
            Mixer.Info mx = Settings.getSavedTargetMixer(persistentSettingsManager);
            TargetDataLine targetDataLine;
            if (mx != null) {
                targetDataLine = (TargetDataLine) AudioSystem.getTargetDataLine(Settings.audioFormatMono,
                        mx);
            } else {
                targetDataLine = (TargetDataLine) AudioSystem.getTargetDataLine(Settings.audioFormatMono);
            }
            targetDataLine.open(Settings.audioFormatMono);

            mx = Settings.getSavedSourceMixer(persistentSettingsManager);
            SourceDataLine sourceDataLine;
            if (mx != null) {
                sourceDataLine = (SourceDataLine) AudioSystem.getSourceDataLine(Settings.audioFormatStereo,
                        mx);
            } else {
                sourceDataLine = sourceDataLine = (SourceDataLine) AudioSystem.getSourceDataLine(Settings.audioFormatStereo);
            }
            sourceDataLine.open(Settings.audioFormatStereo);

            final double A0 = Double.parseDouble(persistentSettingsManager.getProperty(Settings.SettingKeys.A0.name(), "100000.0"));
            final double Rref = Double.parseDouble(persistentSettingsManager.getProperty(Settings.SettingKeys.Rref.name(), "2200.0"));
            final int avgNum = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.avgNum.name(), "20"));
            final int R25 = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.R25.name(), "10000"));
            final int B2580 = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.B2580.name(), "3977"));
            final int R0 = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.R0.name(), "2000"));

            chartXY1.removeAllDatasource();
            chartXY1.getYscale().autoscale(Boolean.parseBoolean(persistentSettingsManager.getProperty(Settings.SettingKeys.isAutoscaleY.name(), "false")));
            double freq = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.avgNum.name(), "50"));
            freq = 44100 / 44 / freq;
            data = new dXYCircularBuffer(Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.chartWindow.name(), "10")) * 1000, (int) freq);
            if (chartXY1.isVisible()) {
                chartXY1.addDataSource(data);
            }

            playProcess = new PlayProcess(sourceDataLine);
            playProcess.setDaemon(true);
            playProcess.start();

            setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
            synchronized (this) {
                try {
                    wait(1000);
                } catch (InterruptedException ex) {
                    Logger.getLogger(SoundcardOhmmeter.class.getName()).log(Level.SEVERE, null, ex);
                }
            }
            setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));

            measureProcess = new MeasureProcess(targetDataLine, avgNum);
            measureProcess.addMeasureResultListener(new MeasureResultListener() {

                boolean isResistance = (persistentSettingsManager.getProperty(Settings.SettingKeys.dataType.name()/*Settings.dataType.class.getName()*/, Settings.dataType.resistance.name()).equals(Settings.dataType.resistance.name())) ? true : false;
                boolean isCelsius = (persistentSettingsManager.getProperty(Settings.SettingKeys.temperatureUnit.name()/*Settings.temperatureUnit.class.getName()*/, Settings.temperatureUnit.celsius.name())).equals(Settings.temperatureUnit.celsius.name()) ? true : false;

                public void measureResultOccured(MeasureResultEvent mre) {
                    double result = (Rref * (A0 - mre.getResult())) / mre.getResult() - R0;

                    if (!isResistance) {
                        result = 1.0 / (1 / 298.16 + Math.log(result / R25) / B2580) - 273.16;
                        if (!isCelsius) {
                            result = (9 / 5) * result + 32;
                        }
                    }
                    resultLabel.setText(nf.format(result) + "");
                    //if (chartXY1.isVisible()) {
                    data.addData(result);
                    //}
                }
            });
            measureProcess.setDaemon(true);
            measureProcess.start();

            startButton.setEnabled(false);
            stopButton.setEnabled(true);
            jRadioButton1.setEnabled(false);
            jRadioButton2.setEnabled(false);
            for (MenuElement m : jMenuBar1.getSubElements()) {
                m.getComponent().setEnabled(false);
            }
        } catch (LineUnavailableException ex) {
            JOptionPane.showMessageDialog(this, "Can't access to Soundcard.", "", JOptionPane.ERROR_MESSAGE);
            Logger.getLogger(SoundcardOhmmeter.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_startButtonActionPerformed

    private void stopButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_stopButtonActionPerformed
        measureProcess.stopReq();
        playProcess.stopReq();
        measureProcess = null;
        playProcess = null;

        startButton.setEnabled(true);
        stopButton.setEnabled(false);
        jRadioButton1.setEnabled(true);
        jRadioButton2.setEnabled(true);
        for (MenuElement m : jMenuBar1.getSubElements()) {
            m.getComponent().setEnabled(true);
        }
    }//GEN-LAST:event_stopButtonActionPerformed

    private void jMenuItem1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jMenuItem1ActionPerformed

        final Boolean pastChart = Boolean.parseBoolean(persistentSettingsManager.getProperty(Settings.SettingKeys.isShowChart.name(), "false"));
        final Integer pastFontSize = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.displayFontSize.name(), "44"));

        JFrame sett = new Settings(persistentSettingsManager);
        sett.setLocationRelativeTo(this);
        sett.setVisible(true);
        sett.addWindowListener(new WindowAdapter() {

            @Override
            public void windowClosed(WindowEvent e) {
                updateView();
                Boolean currChart = Boolean.parseBoolean(persistentSettingsManager.getProperty(Settings.SettingKeys.isShowChart.name(), "false"));
                Integer currFontSize = Integer.parseInt(persistentSettingsManager.getProperty(Settings.SettingKeys.displayFontSize.name(), "44"));
                if (!pastChart.equals(currChart) || !pastFontSize.equals(currFontSize)) {
                    SoundcardOhmmeter.this.setSize(SoundcardOhmmeter.this.getSize().width, SoundcardOhmmeter.this.getPreferredSize().height);
                }
            }
        });

    }//GEN-LAST:event_jMenuItem1ActionPerformed

    private void exportChartMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exportChartMenuItemActionPerformed
        JFileChooser jf = new JFileChooser(persistentSettingsManager.getProperty(Settings.SettingKeys.lastExportLocation.name(), null));
        int res = jf.showSaveDialog(this);
        if (res == JFileChooser.APPROVE_OPTION) {
            try {
                persistentSettingsManager.setProperty(Settings.SettingKeys.lastExportLocation.name(), jf.getSelectedFile().getAbsolutePath());
                if (!jf.getSelectedFile().isFile()) {
                    jf.getSelectedFile().createNewFile();
                }
                GuiTools.saveComponentAsJPEG(chartXY1, jf.getSelectedFile().getAbsolutePath());
            } catch (FileNotFoundException ex) {
                Logger.getLogger(SoundcardOhmmeter.class.getName()).log(Level.SEVERE, null, ex);
                JOptionPane.showMessageDialog(this, "File not found.", "", JOptionPane.ERROR_MESSAGE);
            } catch (IOException ex) {
                Logger.getLogger(SoundcardOhmmeter.class.getName()).log(Level.SEVERE, null, ex);
                JOptionPane.showMessageDialog(this, "I can not get access for file wrting.", "", JOptionPane.ERROR_MESSAGE);
            }
        }
    }//GEN-LAST:event_exportChartMenuItemActionPerformed

    private void jMenuItem3ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jMenuItem3ActionPerformed
        JFileChooser jf = new JFileChooser(persistentSettingsManager.getProperty(Settings.SettingKeys.lastExportLocation.name(), null));
        int res = jf.showSaveDialog(this);
        if (res == JFileChooser.APPROVE_OPTION) {
            try {
                String separator = persistentSettingsManager.getProperty(Settings.SettingKeys.columnSeparator.name(), "\t");
                persistentSettingsManager.setProperty(Settings.SettingKeys.lastExportLocation.name(), jf.getSelectedFile().getAbsolutePath());
                if (!jf.getSelectedFile().isFile()) {
                    jf.getSelectedFile().createNewFile();
                }
                XYArray xy = data.getAsXYArray();
                double[] x = xy.getXdata();
                double[] y = xy.getYdata();

                PrintWriter out = new PrintWriter(new BufferedOutputStream(new FileOutputStream(jf.getSelectedFile())));
                NumberFormat tf = NumberFormat.getNumberInstance();
                tf.setMinimumFractionDigits(2);
                tf.setMaximumFractionDigits(2);
                for (int i = 0; i < y.length; i++) {
                    out.println(tf.format(x[i]) + separator + nf.format(y[i]));
                }
                out.close();
            } catch (IOException ex) {
                Logger.getLogger(SoundcardOhmmeter.class.getName()).log(Level.SEVERE, null, ex);
                JOptionPane.showMessageDialog(this, "I can not get access for file wrting.", "", JOptionPane.ERROR_MESSAGE);
            }
        }
    }//GEN-LAST:event_jMenuItem3ActionPerformed

    private void jMenuItem4ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jMenuItem4ActionPerformed
        StringBuilder sb = new StringBuilder("");
        String separator = persistentSettingsManager.getProperty(Settings.SettingKeys.columnSeparator.name(), "\t");

        XYArray xy = data.getAsXYArray();
        double[] x = xy.getXdata();
        double[] y = xy.getYdata();

        NumberFormat tf = NumberFormat.getNumberInstance();
        for (int i = 0; i < y.length; i++) {
            sb.append(tf.format(x[i]));
            sb.append(separator);
            sb.append(nf.format(y[i]));
            sb.append("\n");
        }

        ClipboardUtils.putPlainTextToSystemClipboard(sb.toString());
    }//GEN-LAST:event_jMenuItem4ActionPerformed

    private void jMenuItem2ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jMenuItem2ActionPerformed
        javax.swing.JFrame panel = new About();
        panel.setLocationRelativeTo(this);
        panel.setVisible(true);
    }//GEN-LAST:event_jMenuItem2ActionPerformed

    private void startButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_startButton1ActionPerformed
        if (!chartXY1.isVisible()) {
            persistentSettingsManager.setProperty(Settings.SettingKeys.isShowChart.name(), Boolean.TRUE.toString());
            if (data != null) {
                chartXY1.addDataSource(data);
            }
        } else {
            persistentSettingsManager.setProperty(Settings.SettingKeys.isShowChart.name(), Boolean.FALSE.toString());
            chartXY1.removeAllDatasource();
        }
        updateView();

        SoundcardOhmmeter.this.setSize(SoundcardOhmmeter.this.getSize().width, SoundcardOhmmeter.this.getPreferredSize().height);
    }//GEN-LAST:event_startButton1ActionPerformed

    private void startButton2ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_startButton2ActionPerformed
        chartXY1.getYscale().autoscaleNext();
    }//GEN-LAST:event_startButton2ActionPerformed

    private void jCheckBox1ItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_jCheckBox1ItemStateChanged
        boolean b = (evt.getStateChange() == ItemEvent.SELECTED) ? true : false;

        persistentSettingsManager.setProperty(Settings.SettingKeys.isAutoscaleY.name(), b+"");
        chartXY1.getYscale().autoscale(b);
    }//GEN-LAST:event_jCheckBox1ItemStateChanged

    private void jRadioButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jRadioButton1ActionPerformed
        if (jRadioButton1.isSelected()){
            persistentSettingsManager.setProperty(Settings.SettingKeys.dataType.name(), Settings.dataType.temperature.name());
            updateView();
        }
    }//GEN-LAST:event_jRadioButton1ActionPerformed

    private void jRadioButton2ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jRadioButton2ActionPerformed
        if (jRadioButton2.isSelected()){
            persistentSettingsManager.setProperty(Settings.SettingKeys.dataType.name(), Settings.dataType.resistance.name());
        }
        updateView();
    }//GEN-LAST:event_jRadioButton2ActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.ButtonGroup buttonGroup1;
    private noise.chart.ChartXY chartXY1;
    private javax.swing.JMenuItem exportChartMenuItem;
    private javax.swing.JCheckBox jCheckBox1;
    private javax.swing.JMenu jMenu2;
    private javax.swing.JMenu jMenu3;
    private javax.swing.JMenu jMenu4;
    private javax.swing.JMenuBar jMenuBar1;
    private javax.swing.JMenuItem jMenuItem1;
    private javax.swing.JMenuItem jMenuItem2;
    private javax.swing.JMenuItem jMenuItem3;
    private javax.swing.JMenuItem jMenuItem4;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JPanel jPanel2;
    private javax.swing.JPanel jPanel3;
    private javax.swing.JPanel jPanel4;
    private javax.swing.JRadioButton jRadioButton1;
    private javax.swing.JRadioButton jRadioButton2;
    private javax.swing.JLabel resultLabel;
    private javax.swing.JButton startButton;
    private javax.swing.JButton startButton1;
    private javax.swing.JButton startButton2;
    private javax.swing.JButton stopButton;
    private javax.swing.JLabel unitLabel;
    // End of variables declaration//GEN-END:variables
}
